@@ -46,7 +46,7 @@ mod tests {
     fn it_works() {
         let a: &[u8] = &[1, 2];
         assert_eq!(
-            a.iter().cloned().lsb0().collect().items,
+            a.iter().cloned().lsb0().collect(Vec::default()).collection,
             vec!(
                 true, false, false, false, false, false, false, false, false, true, false, false,
                 false, false, false, false
@@ -54,7 +54,7 @@ mod tests {
         );
         let v: Vec<u8> = vec![3, 4];
         assert_eq!(
-            v.into_iter().lsb0().collect().items,
+            v.into_iter().lsb0().collect(Vec::default()).collection,
             vec!(
                 true, true, false, false, false, false, false, false, false, false, true, false,
                 false, false, false, false
